@@ -1,9 +1,12 @@
 # -*- coding: utf-8 -*-
 
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 __description__ = 'Library to manage plugins/extensions in your applications.'
 
 import os
+import logging
+
+logger = logging.getLogger('pluginloader')
 
 
 class PluginFactory(object):
@@ -19,14 +22,17 @@ class PluginLoader(object):
         self.plugins = {}
 
     def load_file(self, filename, onlyif=None, context=None):
-        onlyif = self._default_condition if onlyif is None else onlyif
-        context = context or {}
-        with open(filename) as fd:
-            exec(fd.read(), context)
+        try:
+            onlyif = self._default_condition if onlyif is None else onlyif
+            context = context or {}
+            with open(filename) as fd:
+                exec(fd.read(), context)
 
-        for name, clazz in context.items():
-            if (self._apply_condition(onlyif, name, clazz)):
-                self.plugins[name] = PluginFactory(clazz)
+            for name, clazz in context.items():
+                if (self._apply_condition(onlyif, name, clazz)):
+                    self.plugins[name] = PluginFactory(clazz)
+        except:
+            logger.exception('Error loading file %s. Ignored' % filename)
 
     def load_directory(self, path, onlyif=None, recursive=False, context=None):
         for filename in os.listdir(path):
